# frozen_string_literal: true

require 'colorize'

require 'nagios_output/version'
require 'nagios_output/overloads'

#
# Docs to follow
#
module NagiosOutput
    #
    # Docs to follow
    #
    class Nagios
        $use_colour = true

        def self.use_colour(colour = true)
            raise ArgumentError.new('Invalid option: use true or false only') unless [true, false].include? colour

            $use_colour = colour
        end

        singleton_class.send(:alias_method, :use_color, :use_colour)

        def self.check_colour(use_colour_local = nil)
            unless use_colour_local.nil?
                return true if use_colour_local
                return false unless use_colour_local
            end
            return true if $use_colour
            return false unless $use_colour
        end

        def self.clean_string(message)
            return nil if message.nil?

            message = message.to_s.rstrip
            return nil if message.empty?

            message
        end

        def self.ok(message = nil, use_colour_local = nil)
            message = clean_string(message)

            exit 0 if message.nil?

            if check_colour(use_colour_local)
                puts "OK - #{message}".green
            else
                puts "OK - #{message}"
            end
            exit 0
        end

        def self.warning(message = nil, use_colour_local = nil)
            message = clean_string(message)

            exit 1 if message.nil?

            if check_colour(use_colour_local)
                puts "WARNING - #{message}".yellow
            else
                puts "WARNING - #{message}"
            end
            exit 1
        end

        def self.critical(message = nil, use_colour_local = nil)
            message = clean_string(message)

            exit 2 if message.nil?

            if check_colour(use_colour_local)
                puts "CRITICAL - #{message}".red
            else
                puts "CRITICAL - #{message}"
            end
            exit 2
        end

        def self.unknown(message = nil, use_colour_local = nil)
            message = clean_string(message)

            exit 3 if message.nil?

            if check_colour(use_colour_local)
                puts "UNKNOWN - #{message}".blue
            else
                puts "UNKNOWN - #{message}"
            end
            exit 3
        end
    end
end
